Linux gpasswd-Befehl
Linux gpasswd ist ein Verwaltungstool für die Arbeitsgruppendateien /etc/group und /etc/gshadow unter Linux, mit dem ein Benutzer zu einer Gruppe hinzugefügt oder aus einer Gruppe entfernt werden kann.
Syntax
gpasswd [可选项] 组名
Optionale Parameter:
- -a: Fügt einen Benutzer zur Gruppe hinzu;
- -d: Entfernt einen Benutzer aus der Gruppe;
- -A: Einen Administrator angeben;
- -M: Gruppenmitglieder angeben, ähnlich dem Zweck von -A;
- -r: Das Passwort löschen;
- -R: Benutzer daran hindern, sich bei der Gruppe anzumelden; nur Mitglieder der Gruppe können ihr mit newgrp beitreten.
Beispiele
Zum Beispiel gibt es im System ein Konto peter, das kein Mitglied der Gruppe groupname ist. Um newgrp zu verwenden, ist das Passwort erforderlich.
gpasswd groupname
Dies ermöglicht es dem Benutzer, vorübergehend Mitglied der Gruppe zu werden; danach haben auch von peter erstellte Dateien die Gruppe groupname. Auf diese Weise kann peter beim Erstellen von Dateien vorübergehend eine andere Gruppe verwenden, anstelle der Gruppe, zu der peter gehört.
Daher ermöglicht das Festlegen eines Passworts mit gpasswd groupname denjenigen, die das Gruppenpasswort kennen, vorübergehend die Funktionalität der Gruppe groupname zu nutzen.
gpasswd -A peter users
Auf diese Weise wird peter Administrator der Gruppe users und kann die folgenden Operationen ausführen:
gpasswd -a mary users gpasswd -a allen users
Hinweis: Um einen Benutzer zu einer Gruppe hinzuzufügen, können Sieusermod -G group_name user_nameverwenden. Dieser Befehl kann einen Benutzer zu einer angegebenen Gruppe hinzufügen, aber die zuvor hinzugefügten Gruppen werden gelöscht.
Wenn Sie daher einen Benutzer zu einer Gruppe hinzufügen möchten und die zuvor hinzugefügten Gruppen beibehalten wollen, verwenden Sie bitte den Befehl gpasswd, um den Benutzer hinzuzufügen:
gpasswd -a user_name group_nameAndere Erweiterungen
Linux-Befehlssammlung